function model=update_model(model)
% Returns the updated Thermotoga maritima model iTZ479_v2
%
% Usage:
%    model=update_model(modeliTZ479) where modeliTZ479 is the original TM
%    reconstruction (Science. 2009;325:1544-9.)

model.metCharge=cell2mat(model.metCharge);

fprintf('Before updating\n')
printRxnFormula(model,'HYDFDi');
printRxnFormula(model,'OOR2');
printRxnFormula(model,'POR');

% Adjust stoichiometry to the 4:4 form of ferrodoxin

% Rename ferrodoxin metabolite
model.mets{findMetIDs(model,'fdxo-4-2[c]')}='fdxo-4-4[c]';
model.mets{findMetIDs(model,'fdxr-4-2[c]')}='fdxr-4-4[c]';

% Update the stoichiometry of the coresponding reactions
model.S(findMetIDs(model,'fdxr-4-4[c]'), findRxnIDs(model,'HYDFDi')) = -2;
model.S(findMetIDs(model,'fdxo-4-4[c]'), findRxnIDs(model,'HYDFDi')) = 2;

model.S(findMetIDs(model,'fdxo-4-4[c]'), findRxnIDs(model,'OOR2')) = -2;
model.S(findMetIDs(model,'fdxr-4-4[c]'), findRxnIDs(model,'OOR2')) = 2;

model.S(findMetIDs(model,'fdxo-4-4[c]'), findRxnIDs(model,'POR')) = -2;
model.S(findMetIDs(model,'fdxr-4-4[c]'), findRxnIDs(model,'POR')) = 2;

% Add the bifurcating hydrogenase
model = addReaction(model,'BHYH2', '[c] : 2 fdxr-4-4 + nadh +  3 h <==> 2 fdxo-4-4 + nad + 2 h2');

% Add 6-phosphogluconate dehydratase
model = addReaction(model,'EDD', '[c] : 6pgc --> 2ddg6p + h2o');

% Add NADH:ferredoxin oxidoreductase
model = addReaction(model,'NFO', '[c] : 2 fdxr-4-4 + nad + h --> 2 fdxo-4-4 + nadh');

% The NAD_H2 and HYDFDi reactions are no longer used
model=changeRxnBounds(model,'NAD_H2',0,'l');
model=changeRxnBounds(model,'NAD_H2',0,'u');
model=changeRxnBounds(model,'HYDFDi',0,'u');

fprintf('\nAfter updating\n')
printRxnFormula(model,'HYDFDi');
printRxnFormula(model,'OOR2');
printRxnFormula(model,'POR');
printRxnFormula(model,'BHYH2');

% Enable lactate secretion by reversing directionality of L_LACt2
fprintf('Adding lactate secretion\n')
idx=findRxnIDs(model,'L_LACt2');
model.lb(idx)=-1000;
model.rev(idx)=1;

fprintf('Adding alanine transport\n')
model=addReaction(model,'ALAts','ala-L[c] -> ala-L[e]');

fprintf('Removing glucuronosyltransferase rxn\n')
model=changeRxnBounds(model,'GLCURT',0,'b');
